@@ -9,9 +9,7 @@ use fields qw( fh filename );
 
 use vars qw[ $VERSION ];
 
-use IO::File;
-
-$VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.16 $ =~ /: (\d+)\.(\d+)/;
 
 # Prevents death later on if IO::File can't export this constant.
 BEGIN
@@ -53,11 +51,11 @@ sub _make_handle
     $self->{filename} = $params{filename};
 
     my $mode;
-    if ( exists $params{mode}
-	 &&
-	 ( $params{mode} =~ /^>>$|^append$|/
-	   ||
-	   $params{mode} == O_APPEND() ) )
+    if ( exists $params{mode} &&
+	 defined $params{mode} &&
+	 ( $params{mode} =~ /^>>$|^append$/ ||
+	   ( $params{mode} =~ /^\d+$/ &&
+	     $params{mode} == O_APPEND() ) ) )
     {
 	$mode = '>>';
     }
@@ -66,9 +64,14 @@ sub _make_handle
 	$mode = '>';
     }
 
-    $self->{fh} = IO::File->new("$mode$self->{filename}")
+    my $fh = do { local *FH; *FH; };
+    open $fh, "$mode$self->{filename}"
 	or die "Can't write to '$self->{filename}': $!";
-    $self->{fh}->autoflush(1);
+
+    # turn on autoflush
+    my $oldfh = select $fh; $| = 1; select $oldfh;
+
+    $self->{fh} = $fh;
 }
 
 sub log_message
@@ -76,7 +79,19 @@ sub log_message
     my Log::Dispatch::File $self = shift;
     my %params = @_;
 
-    $self->{fh}->print($params{message});
+    my $fh = $self->{fh};
+    print $fh $params{message};
+}
+
+sub DESTROY
+{
+    my $self = shift;
+
+    if ( $self->{fh} )
+    {
+	my $fh = $self->{fh};
+	close $fh;
+    }
 }
 
 __END__
@@ -169,3 +184,4 @@ Log::Dispatch::Email::MIMELite, Log::Dispatch::Handle,
 Log::Dispatch::Output, Log::Dispatch::Screen, Log::Dispatch::Syslog
 
 =cut
+                       
