@@ -9,7 +9,7 @@ use vars qw[ $VERSION ];
 
 use Carp ();
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.18 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.19 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -196,17 +196,16 @@ means functionally that the object has no maximum).
 
 This parameter may be a single subroutine reference or an array
 reference of subroutine references.  These callbacks will be called in
-the order they are given and passed a hash containing the following
-keys:
+the order they are given and passed a hash containing the following keys:
 
- ( message => $log_message )
-
-It's a hash in case I need to add parameters in the future.
+ ( message => $log_message, level => $log_level )
 
 The callbacks are expected to modify the message and then return a
 single scalar containing that modified message.  These callbacks will
 be called when either the C<log> or C<log_to> methods are called and
-will only be applied to a given message once.
+will only be applied to a given message once.  If they do not return
+the message then you will get no output.  Make sure to return the
+message!
 
 =item * _basic_init(%PARAMS)
 
