@@ -10,22 +10,20 @@ BEGIN { $| = 1; print "1..122\n"; }
 END {print "not ok 1\n" unless $main::loaded;}
 
 use strict;
+$^W = 1;
 
 use Log::Dispatch;
 
 my %tests;
 BEGIN
 {
-    eval "use Log::Dispatch::Email::MailSend;";
-    $tests{MailSend} = ! $@;
+    foreach ( qw( MailSend MIMELite Sendmail ) )
+    {
+	eval "use Log::Dispatch::Email::$_";
+	$tests{$_} = ! $@;
+    }
 
-    eval "use Log::Dispatch::Email::MIMELite;";
-    $tests{MIMELite} = ! $@;
-
-    eval "use Log::Dispatch::Email::MailSendmail;";
-    $tests{MailSendmail} = ! $@;
-
-    eval "use Log::Dispatch::Syslog;";
+    eval "use Log::Dispatch::Syslog";
     $tests{Syslog} = ! $@;
 }
 
@@ -379,7 +377,7 @@ Screen:
 
 # 20 - 107: Comprehensive test of new methods that match level names
 {
-    my %levels = map { $_ => $_ } ( qw( debug info notice warning err error crit critical alert emerg emergency ) );
+    my %levels = map { $_ => $_ } ( qw( debug info notice warning error critical alert emergency ) );
     @levels{ qw( err crit emerg ) } = ( qw( error critical emergency ) );
 
     foreach my $allowed_level ( qw( debug info notice warning error critical alert emergency ) )
@@ -400,8 +398,9 @@ Screen:
 
 	    if ( $levels{$test_level} eq $allowed_level )
 	    {
-		result( $text eq (join $,, $test_level, 'test'),
-			"Calling $test_level method should have sent message '$test_level test'\n" );
+		my $expect = join $", $test_level, 'test';
+		result( $text eq $expect,
+			"Calling $test_level method should have sent message '$expect'\n" );
 	    }
 	    else
 	    {
@@ -425,6 +424,32 @@ Screen:
     }
 }
 
+# 123: make sure passing mode as write works
+{
+    local *F;
+    open F, '>./write_mode.tst'
+	or die "Cannot open ./write_mode.tst: $!";
+    print F "test1\n";
+    close F;
+
+    my $f1 = Log::Dispatch::File->new( name => 'file',
+				       min_level => 1,
+				       filename => './write_mode.tst',
+				       mode => 'write',
+				      );
+    $f1->log( level => 'emerg',
+	      message => "test2\n" );
+
+    undef $f1;
+
+    open F, '<./write_mode.tst'
+	or die "Cannot read ./write_mode.tst: $!";
+    my $data = join '', <F>;
+    close F;
+
+    result( $data =~ /^test2/ );
+}
+
 sub fake_test
 {
     my ($x, $pm) = @_;
@@ -452,6 +477,7 @@ sub TIEHANDLE
     my $class = shift;
     my $self = {};
     $self->{string} = shift;
+    ${ $self->{string} } ||= '';
 
     return bless $self, $class;
 }
